@@ -17,13 +17,16 @@ def _ampl_license_cell(check_callback):
     import ipywidgets as widgets
     from IPython.display import display
 
-    platform = cloud_platform_name()
-    if platform is not None:
-        print("AMPL License UUID (you can use a free https://ampl.com/ce license):")
-    else:
-        print("AMPL License UUID:")
+    header = widgets.Output()
     message = widgets.Output()
     version = widgets.Output()
+
+    platform = cloud_platform_name()
+    with header:
+        if platform is not None:
+            print("AMPL License UUID (you can use a free https://ampl.com/ce license):")
+        else:
+            print("AMPL License UUID:")
     with message:
         ampl_lic = os.environ.get("AMPL_LICFILE", None)
         if ampl_lic is not None and platform is None:
@@ -64,33 +67,47 @@ def _ampl_license_cell(check_callback):
 
     existing_btn.on_click(lambda b: activate("existing"), False)
     uuid_input.observe(lambda d: activate("uuid"), "value")
-    display(widgets.VBox([widgets.HBox([existing_btn, uuid_input]), message, version]))
+    display(
+        widgets.VBox(
+            [header, widgets.HBox([existing_btn, uuid_input]), message, version]
+        )
+    )
 
 
 def _handle_default_uuid():
-    if "AMPL_LICFILE" not in os.environ and cloud_platform_name() == "colab":
-        try:
-            from ampl_module_base import bin_dir
+    if "AMPL_LICFILE" in os.environ:
+        return os.environ.get("AMPL_LICFILE", "") == os.environ.get(
+            "AMPL_LICFILE_DEFAULT", ""
+        )
+    if cloud_platform_name() != "colab":
+        return False
+    try:
+        from ampl_module_base import bin_dir
 
-            _activate_default_license(bin_dir, "colab")
-        except:
-            print("Failed to activate default license.")
+        _activate_default_license(bin_dir, "colab")
+        return True
+    except:
+        print("Failed to activate default license.")
+        return False
 
 
 def ampl_notebook(
-    modules=None,
+    modules=[],
     license_uuid=None,
     reinstall=False,
-    globals_=None,
+    g=None,
     verbose=False,
     register_magics=True,
     show_license=None,
+    globals_=None,
 ):
+    if globals_ is None:
+        globals_ = g
     show_prompt = globals_ is not None
-    if show_license is None:
-        show_license = show_prompt
     if globals_ is None:
         globals_ = {}
+    if show_license is None:
+        show_license = True
 
     def instantiate_ampl(print_license=True):
         from amplpy import AMPL, Environment
@@ -117,11 +134,26 @@ def ampl_notebook(
     install_modules(modules, reinstall=reinstall, verbose=verbose)
     load_modules(modules, verbose=verbose)
 
-    if license_uuid is None or license_uuid == "default":
-        _handle_default_uuid()
+    using_default_license = license_uuid in (None, "", "default", "your-license-uuid")
+    open_modules = ["highs", "cbc", "coin", "open", "plugins", "ampl"]
+    open_source_only = len(set(modules) - set(open_modules)) == 0
 
-    if license_uuid == "default":
-        instantiate_ampl(print_license=show_license)
+    if using_default_license:
+        using_default_license = _handle_default_uuid()
+    if using_default_license:
+        if show_prompt and open_source_only:
+            show_prompt = False
+        if not show_prompt:
+            print(
+                "Using default Community Edition License for Colab. "
+                "Get yours at: https://ampl.com/ce"
+            )
+
+    if using_default_license:
+        if show_prompt:
+            _ampl_license_cell(check_callback=instantiate_ampl)
+        else:
+            instantiate_ampl(print_license=show_license)
     elif not is_valid_uuid(license_uuid):
         if license_uuid not in (None, ""):
             print(
